==> haskell-quickcheck-text-0.1.2.1-126-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-EH2tRE5TXPd3lB4Ub8hd0K
key:                  quickcheck-text-0.1.2.1-EH2tRE5TXPd3lB4Ub8hd0K
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  88bb25416ebac3118fec9ebb07aba999
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-text
hs-libraries:         HSquickcheck-text-0.1.2.1-EH2tRE5TXPd3lB4Ub8hd0K
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-text-0.1.2.1-128-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-quickcheck-text.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 quickcheck-text
version:              0.1.2.1
visibility:           public
id:                   quickcheck-text-0.1.2.1-JSufvguP5SjL9q4891kyuY
key:                  quickcheck-text-0.1.2.1-JSufvguP5SjL9q4891kyuY
license:              MIT
copyright:            2015-2016 Sharif Olorin and others
maintainer:           sio@tesser.org
author:               Sharif Olorin
homepage:             https://github.com/olorin/quickcheck-text
synopsis:             Alternative arbitrary instance for Text
description:
    The usual Arbitrary instance for Text
    (in
    <https://hackage.haskell.org/package/quickcheck-instances quickcheck-instances>)
    only has single-byte
    instances and so isn'\''t an ideal representation of a valid UTF-8
    character. This package has generators for one-, two- and three-byte
    UTF-8 characters (all that are currently in use).

category:             Text
abi:                  c1884712c31e6b2f44c918f19ac97ef4
exposed:              True
exposed-modules:      Data.Text.Arbitrary Test.QuickCheck.Utf8
import-dirs:          /usr/lib/ghc-9.2.8/site-local/quickcheck-text-0.1.2.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/quickcheck-text-0.1.2.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-quickcheck-text
hs-libraries:         HSquickcheck-text-0.1.2.1-JSufvguP5SjL9q4891kyuY
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    binary-0.8.9.0 bytestring-0.11.4.0 text-1.2.5.0

haddock-interfaces:
    /usr/share/doc/haskell-quickcheck-text/html/quickcheck-text.haddock

haddock-html:         /usr/share/doc/haskell-quickcheck-text/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
